@@ -3,17 +3,13 @@ use std::fs::{DirBuilder, DirEntry, File, OpenOptions};
 use std::io::{BufRead, BufReader, Seek, SeekFrom, Write, Error};
 
 use chrono::{Local, NaiveDateTime};
-use zip::write::FileOptions;
 
 use crate::appender::{Command, FastLogRecord, LogAppender};
 use crate::consts::LogSize;
 use std::ops::Sub;
 use std::time::Duration;
-use cogo::go;
-use cogo::std::channel::{Receiver, Sender};
-
-use zip::result::ZipResult;
 use crate::error::LogError;
+use crate::{chan, Receiver, Sender};
 
 /// .zip or .lz4 or any one packer
 pub trait Packer: Send {
@@ -213,7 +209,7 @@ impl FileSplitAppender {
             temp_bytes = m.len() as usize;
         }
         file.seek(SeekFrom::Start(temp_bytes as u64));
-        let (sender, receiver) = cogo::std::sync::mpsc::channel();
+        let (sender, receiver) = chan();
         spawn_saver(file_name,receiver, packer);
         Self {
             cell: RefCell::new(FileSplitAppenderData {
